==> org.eclipse.jgit.source_5.2.0.201812061821-r.jar: org/eclipse/jgit/lib/ReflogReader.java <==
/*
 * Copyright (C) 2013, Robin Rosenberg <robin.rosenberg@dewire.com>
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.lib;

import java.io.IOException;
import java.util.List;

/**
 * Utility for reading reflog entries
 *
 * @since 3.0
 */
public interface ReflogReader {

	/**
	 * Get the last entry in the reflog
	 *
	 * @return the latest reflog entry, or null if no log
	 * @throws java.io.IOException
	 */
	ReflogEntry getLastEntry() throws IOException;

	/**
	 * Get all reflog entries in reverse order
	 *
	 * @return all reflog entries in reverse order
	 * @throws java.io.IOException
	 */
	List<ReflogEntry> getReverseEntries() throws IOException;

	/**
	 * Get specific entry in the reflog relative to the last entry which is
	 * considered entry zero.
	 *
	 * @param number a int.
	 * @return reflog entry or null if not found
	 * @throws java.io.IOException
	 */
	ReflogEntry getReverseEntry(int number) throws IOException;

	/**
	 * Get all reflog entries in reverse order
	 *
	 * @param max
	 *            max number of entries to read
	 * @return all reflog entries in reverse order
	 * @throws java.io.IOException
	 */
	List<ReflogEntry> getReverseEntries(int max) throws IOException;
}

==> org.eclipse.jgit.source_7.5.0.202512021534-r.jar: org/eclipse/jgit/lib/ReflogReader.java <==
/*
 * Copyright (C) 2013, Robin Rosenberg <robin.rosenberg@dewire.com> and others
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0 which is available at
 * https://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.eclipse.jgit.lib;

import java.io.IOException;
import java.util.List;

/**
 * Utility for reading reflog entries
 *
 * @since 3.0
 */
public interface ReflogReader {

	/**
	 * Get the last entry in the reflog
	 *
	 * @return the latest reflog entry, or null if no log
	 * @throws java.io.IOException
	 *             if an IO error occurred
	 */
	ReflogEntry getLastEntry() throws IOException;

	/**
	 * Get all reflog entries in reverse order
	 *
	 * @return all reflog entries in reverse order
	 * @throws java.io.IOException
	 *             if an IO error occurred
	 */
	List<ReflogEntry> getReverseEntries() throws IOException;

	/**
	 * Get specific entry in the reflog relative to the last entry which is
	 * considered entry zero.
	 *
	 * @param number
	 *            a int.
	 * @return reflog entry or null if not found
	 * @throws java.io.IOException
	 *             if an IO error occurred
	 */
	ReflogEntry getReverseEntry(int number) throws IOException;

	/**
	 * Get all reflog entries in reverse order
	 *
	 * @param max
	 *            max number of entries to read
	 * @return all reflog entries in reverse order
	 * @throws java.io.IOException
	 *             if an IO error occurred
	 */
	List<ReflogEntry> getReverseEntries(int max) throws IOException;
}
